# Griechischer Kartoffeltopf

Das ist ein sehr leckeres Rezept.

*vegetarisch, griechisch*

**6 Portionen**

--- 
 
## Gemüsebasis

- *1 Bund* glatte Petersilie
- *2 TL* Salz
- *1 Prise* Pfeffer
- *1 Prise* Oregano
- *1 Prise* Zimt
- *800 g* festkochende Kartoffeln
- *3 EL* neutrales Öl
- *1* Gemüsezwiebel
- *250 g* Zucchini
- *250 g* Tomaten

## Käsebelag

- *100 g* Schafkäse
- *100 g* Schmand
- *100 g* Sahne

---

Die Petersilie waschen und fein hacken. Salz mit Pfeffer, Oregano, Zimt und Petersilie mischen.
Das Gemüse waschen. Kartoffeln schälen und in dünne Scheiben schneiden. Das Öl in einem großen Topf erhitzen, Kartoffeln darin anbraten, mit einem Teil der Würzmischung bestreuen und im geschlossenen Topf bei kleiner Hitze schmoren.

Inzwischen die Zwiebel schälen und klein würfeln, auf die Kartoffeln geben, würzen, mit geschlossenem Deckel weiter schmoren.

Zucchini in Scheiben schneiden, in den Topf geben und würzen, mit geschlossenem Deckel weiter schmoren.

Tomaten mit kochendem Wasser überbrühen, etwa 1 Min. ziehen lassen, die Haut abziehen, vierteln, Stielansätze und Kernchen entfernen. Fruchtfleisch auf dem Gemüse verteilen und im geschlossenen Topf in etwa 15 Min. garen.

Den Käse mit Schmand und Sahne pürieren, auf dem Gemüse verteilen und nochmals 5-10 Min. erhitzen.
